@@ -51,7 +51,7 @@ __all__ = (
 )
 
 
-__version__ = '0.12.5'
+__version__ = '0.12.6'
 
 
 def model_form_meta_factory(base=FormMeta):
@@ -99,6 +99,9 @@ def model_form_meta_factory(base=FormMeta):
                 if 'Meta' in class_.__dict__:
                     bases.append(getattr(class_, 'Meta'))
 
+            if not object in bases:
+                bases.append(object)
+
             cls.Meta = type('Meta', tuple(bases), {})
 
             base.__init__(cls, *args, **kwargs)
@@ -144,7 +147,7 @@ def model_form_factory(base=Form, meta=ModelFormMeta, **defaults):
         if not hasattr(base, 'get_session'):
             get_session = None
 
-        class Meta:
+        class Meta(object):
             model = None
 
             default = None
@@ -286,13 +289,13 @@ class ModelCreateForm(ModelForm):
 
 
 class ModelUpdateForm(ModelForm):
-    class Meta:
+    class Meta(object):
         all_fields_optional = True
         assign_required = False
 
 
 class ModelSearchForm(ModelForm):
-    class Meta:
+    class Meta(object):
         all_fields_optional = True
         only_indexed_fields = True
         include_primary_keys = True
